var player = null;
var previousChannel = null;
var lastRetry = null;
var managerUrl = null;
var playerToken = null;
var playerProtocol = null;
var epgData = { channelId: null, currentProgram: null, nextProgram: null };

function setManager(url) {
    managerUrl = url;
}

function setToken(token) {
    playerToken = token;
}

function setProtocol(protocol) {
    playerProtocol = protocol;
}

function initChannel(ch, stop) {
  var currentChannelSource = playerProtocol + "://" + managerUrl + ch.hls + "&t=" + playerToken;

    player = new Clappr.Player({
      source: currentChannelSource,
        parentId: "#player",
        width: "100%",
        height: "100%",
        chromeless: false,
        poster: isAudioOnly(ch) ? ch.poster : "",
        plugins: {
            'core': [LevelSelector]
        },

        /*levelSelectorConfig: {
            title: 'Quality',
            labels: {
                1: 'High 720p',
                0: 'Med 480p',
            },
        },*/

        language: 'pt-BR',
        strings: {
            'pt-BR': {
                'live': 'Ao Vivo',
                'back_to_live': 'Voltar para o Ao Vivo',
                'disabled': 'Desativado',
                'playback_not_supported': 'Este navegador ou dispositivo não suportam a reprodução deste vídeo.'
            }
        }
    });

    player.on(Clappr.Events.PLAYER_ERROR, function(error) {
        recoverError();
    });

    if(stop) {
        player.configure({
            chromeless: true,
            allowUserInteraction: false,
            poster: isAudioOnly(ch) ? ch.poster : ""
        });
        $('.spinner-three-bounce').hide();
        player.stop();
    } else {
        player.play();
        activateChannel(ch);
    }
    // resizePlayer();
}

function recoverError() {
    var now = new Date();

    //Retry play on same channel for one minute
    if (!lastRetry) {
        player.stop();
        player.play();
        lastRetry = now.setSeconds(now.getSeconds() + 60);

        setTimeout(function () {
            recoverError();
        }, 1000);
    } else {

        if(!player.isPlaying()) {
            if (now <= lastRetry) {
                player.play();

                setTimeout(function () {
                    recoverError();
                }, 1000);
            } else {
                showPlayerError();
                lastRetry = null;

                setTimeout(function () {
                    retryConnection();
                }, 30000);
            }
        }
    }
}

function retryConnection() {
    if(!player.isPlaying()) {
        player.play();
    }
}

function isAudioOnly(ch){
    if (ch.aonly == "undefined" || ch.aonly == null || ch.aonly == false){
        return false;
    }
    return true;
}

function switchChannel(ch) {
  var currentChannelSource = playerProtocol + "://" + managerUrl + ch.hls + "&t=" + playerToken;

  if (player) {
    player.configure({
      source: currentChannelSource,
      chromeless: false,
      poster: isAudioOnly(ch) ? playerProtocol + "://" + managerUrl + "/" + ch.poster : ""
    });
    player.play();
    activateChannel(ch);
    } else {
    initChannel(ch, false);
    }

    initEpg();
}

// function resizePlayer(){
//     if(player) {
//       player.core.mediaControl.toggleFullscreen();
//     }
// }

function activateChannel(ch) {
    if(previousChannel) {
      if(document.getElementById('ch'+previousChannel.id+'-play')) {
        document.getElementById('ch' + previousChannel.id + '-play').style.display = 'none';
        document.getElementById('ch' + previousChannel.id + '-num').style.display = 'block';
        document.getElementById('ch' + previousChannel.id + '-watching').style.display = 'none';
        document.getElementById('ch' + previousChannel.id + '-watching-label').style.display = 'none';
      }
    }

    document.getElementById('ch'+ch.id+'-play').style.display = 'block';
    document.getElementById('ch'+ch.id+'-num').style.display = 'none';
    document.getElementById('ch'+ch.id+'-watching').style.display = 'block';
    document.getElementById('ch'+ch.id+'-watching-label').style.display = 'block';

    //document.getElementById('channel-name').innerHTML = ch.name;
    //document.getElementById('channel-logo').src = "";

    previousChannel = ch;
}

function activateChannelsBody() {
    document.getElementById('no-channels').style.display = 'none';
    document.getElementById('has-channels').style.display = 'block';
}

function deactivateChannelsBody() {
    if(player) {
      player.stop();
      player = null;
    }
    document.getElementById('no-channels').style.display = 'block';
    document.getElementById('has-channels').style.display = 'none';
}

// function playerEnterFullscreen() {
//     if(player) {
//       player.core.mediaControl.toggleFullscreen();
//     }
// }

function showHeader() {
    var divs = document.getElementsByClassName("scroll-content");
    for(var i=0; i<divs.length; i++) {
      document.getElementsByClassName("scroll-content")[i].style.marginTop = "56px";
    }
}

function hideHeader() {
    var divs = document.getElementsByClassName("scroll-content");
    for(var i=0; i<divs.length; i++) {
      document.getElementsByClassName("scroll-content")[i].style.marginTop = "0px";
    }
}

function createEpg() {
    var ch = previousChannel;
    var ch_id = previousChannel.id;
    var current_time = new Date();
    var current_program_end_time = null;

    if(epgData.currentProgram) {
        current_program_end_time = new Date(epgData.currentProgram.stop.replace(" ", "T") + "Z");
    }

    console.log(ch.guide)

    if((ch_id != epgData.channelId || current_time > current_program_end_time) && ch.guide) {
        var myHeaders = new Headers();
        myHeaders.set("Accept", "application/json");
        myHeaders.set("Content-Type", "application/json");
        
        var myInit = { method: 'GET', headers: myHeaders, mode: 'cors', cache: 'default' };

        getUrl = playerProtocol + "://" + managerUrl+ch.guide+"?t="+playerToken+"&now";
        fetch(getUrl, myInit).then(response => {
            return response.json();
        }).then(response => {
            var current_program = null, next_program = null;

            if(response[0]) {
                current_program = response[0];
            }
            if(response[1]) {
                next_program = response[1];
            }

            epgData = {
                channelId: ch_id,
                currentProgram: current_program,
                nextProgram: next_program
            };

            showEpg();
            console.log("SuccessGuide:");
        })
        .catch((error) => {
            hideEpg();
            console.log("ErrorGuide:");
            console.log(error);

            //Search again just after 5 minutes
            epgData = {
                channelId: ch_id
            };
            researchEpg = new Date();
            researchEpg.setMinutes(researchEpg.getMinutes()+5);
        });

    }
}

function initEpg() {
    epgData = { channelId: null, currentProgram: null, nextProgram: null };

    player.listenTo(player.core.getCurrentContainer(),
        Clappr.Events.CONTAINER_MEDIACONTROL_SHOW,
        function() {
            if($('#epg-info').length == 0) {
                $('.media-control-background').append('<div id="epg-info" class="epg-info"></div>');

                $('#epg-info').append('<div id="epg-current" class="epg-program"></div>');
                $('#epg-info').append('<div id="epg-next" class="epg-program"></div>');

                $('#epg-current').append('<div><span class="epg-program-time"></span><span class="epg-program-name"><span class="epg-program-label">Agora</span></span></div>');
                $('#epg-current').append('<div><span class="epg-program-time" id="epg-current-program-time"></span><span class="epg-program-name" id="epg-current-program"></span></div>');

                $('#epg-next').append('<div><span class="epg-program-time"></span><span class="epg-program-name"><span class="epg-program-label">A Seguir</span></span></div>');
                $('#epg-next').append('<div><span class="epg-program-time" id="epg-next-program-time"></span><span class="epg-program-name" id="epg-next-program"></span></div>');
            }

            createEpg();
        }
    );
}

function showEpg() {
    if(epgData.currentProgram) {
        var start = new Date(epgData.currentProgram.start.replace(" ", "T") + "Z");
        var startText = ('0' + start.getHours()).slice(-2) + ":" + ('0' + start.getMinutes()).slice(-2);

        var stop = new Date(epgData.currentProgram.stop.replace(" ", "T") + "Z");
        var stopText = ('0' + stop.getHours()).slice(-2) + ":" + ('0' + stop.getMinutes()).slice(-2);

        $('#epg-current-program-time').text(startText + " - " + stopText);
        $('#epg-current-program').text(epgData.currentProgram.title);
        $('#epg-current').show();
    } else {
        $('#epg-current').hide();
    }

    if(epgData.nextProgram) {
        var start = new Date(epgData.nextProgram.start.replace(" ", "T") + "Z");
        var startText = ('0' + start.getHours()).slice(-2) + ":" + ('0' + start.getMinutes()).slice(-2);

        var stop = new Date(epgData.nextProgram.stop.replace(" ", "T") + "Z");
        var stopText = ('0' + stop.getHours()).slice(-2) + ":" + ('0' + stop.getMinutes()).slice(-2);

        $('#epg-next-program-time').text(startText + " - " + stopText);
        $('#epg-next-program').text(epgData.nextProgram.title);
        $('#epg-next').show();
    } else {
        $('#epg-next').hide();
    }
    console.log("success")
}

function hideEpg() {
    $('#epg-current').hide();
    $('#epg-next').hide();
}

function showPlayerError(ch) {
    if(player) {
        player.configure({
            chromeless: true,
            allowUserInteraction: false,
            poster: isAudioOnly(ch) ? ch.poster : ""
        });
        player.stop();
    } else {
        if(ch) {
            initChannel(ch, true);
        }
    }

  if ($('#playlist-channel-info').length === 0) {
    $('.player-poster').append('<div id="playlist-channel-info" class="playlist-channel-info" style="display:none;"></div>');
    }

  $('#playlist-channel-info').text("Canal não pode ser exibido! Tentando reconectar...");
  $('#playlist-channel-info').show();
}

function stopPlayer() {
    if(player) {
        player.stop();
    }
}

function hardStopPlayer() {
  if (player) {
    player.stop();
    player = null;
  }
}

function startPlayer() {
    if(player) {
        player.play();
    }
}
